@@ -14,7 +14,7 @@ use Data::Table::Text qw(:all);
 use File::Copy;
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 
-our $VERSION = '2017.528';
+our $VERSION = '2017.612';
 
 #-------------------------------------------------------------------------------
 # Constants
@@ -59,7 +59,7 @@ if (1)
   qw(parameters),                                                               # Parameter string to be placed in res for the app
   qw(permissions),                                                              # Permissions, a standard useful set is applied
   qw(platform),                                                                 # Folder containing 'android.jar' - for example Android/sdk/platforms/25.0.2
-  qw(platformTools),                                                            # Folder containing Android sdk platform tools
+  qw(platformTools),                                                            # Folder containing 𝗮𝗱𝗯
   qw(sdkLevels),                                                                # [minSdkVersion,targetSdkVersion], default is [15,25]
   qw(src),                                                                      # Source of app, default is everything in './src' folder
   qw(title),                                                                    # Title of app, default is name of app
@@ -382,11 +382,11 @@ sub create
   my $name      = $android->appName;
   my $activity  = $android->activity;
   my $package   = $android->getPackage;
-  if (-d $buildArea)
-   {my $r = xxx("rm -r $buildArea");                                            # Clear build area
-    !$r or confess "Unable to remove existing app build area:\n".
-                   "$buildArea\n$r\n";
-   }
+#  if (-d $buildArea)  # Not doing this saves two seconds
+#   {my $r = xxx("rm -r $buildArea");                                            # Clear build area
+#    !$r or confess "Unable to remove existing app build area:\n".
+#                   "$buildArea\n$r\n";
+#   }
   $android->pushIcons;                                                          # Create icons
   $android->copySource;                                                         # Copy source
   $android->copyLibs;                                                           # Copy libraries
@@ -434,6 +434,8 @@ sub make
   my $gen        = $android->appGenFolder;
   my $res        = $android->appResFolder;
   my $src        = $android->appSrcFolder;
+  my $libs       = $android->appLibsFolder;
+  my @libs       = grep {/\.jar\Z/} findFiles(filePathDir($libs));              # Find libraries == jar files
   my $manifest   = $android->manifestFile;
   my $binRes     = filePath($bin, $res);
   my $classes    = filePath($bin, qw(classes));
@@ -497,14 +499,16 @@ sub make
       findFiles(filePathDir($src)),
       findFiles(filePathDir($gen));
 
-    my $r = xxx("javac -source  7 -target 7 -cp $androidJar -d $classes $j");
+    my $J = join ':', $androidJar, @libs;                                       # Jar files for javac
+
+    my $r = xxx("javac -g -source  7 -target 7 -cp $J -d $classes $j");
     $r !~ /error/ or confess "Java errors\n";
     $android->logMessage($r);
    }
 
   if (1)                                                                        # Dx
-   {makePath($classes);
-    my $r = xxx("$dx --dex --force-jumbo --output $classes.dex $classes");
+   {my $j = join ' ', @libs;                                                    # Jar files to include in dex
+    my $r = xxx("$dx --dex --force-jumbo --output $classes.dex $classes $j");
     $android->logMessage($r);
    }
 
